<!--
 * @Author: zouyaoji@https://github.com/zouyaoji
 * @Date: 2021-10-27 15:54:11
 * @LastEditTime: 2022-12-08 22:05:17
 * @LastEditors: zouyaoji
 * @Description:
 * @FilePath: \vue-cesium@next\website\docs\zh-CN\i18n.md
-->

## 国际化

Vue for Cesium 组件内部**默认**使用英语，若希望使用其他语言，可以参考下面的方案。

### 全局配置

Vue for Cesium 提供了全局配置国际化的设置。

```typescript
import { createApp } from 'vue'
import VueCesium from 'vue-cesium'
import enUS from 'vue-cesium/es/locale/lang/en-us'

const app = createApp(App)
app.use(VueCesium, {
  locale: enUS
})
app.mount('#app')
```

### VcConfigProvider

Vue for Cesium 还提供了一个 Vue 组件 [VcConfigProvider](/#/zh-CN/component/vc-config-provider) 用于全局配置国际化的设置。

```html
<template>
  <vc-config-provider :locale="locale">
    <vc-viewer>
      <vc-navigation></vc-navigation>
    </vc-viewer>
  </vc-config-provider>
</template>

<script>
  import { defineComponent } from 'vue'
  import { VcConfigProvider, VcViewer, VcNavigation } from 'vue-cesium'

  import enUS from 'vue-cesium/es/locale/lang/en-us'

  export default defineComponent({
    components: {
      VcConfigProvider,
      VcViewer,
      VcNavigation
    },
    setup() {
      return {
        locale: enUS
      }
    }
  })
</script>
```

<!-- ### CDN 用法

如果你是使用 CDN 引入的 VueCesium，那你将需要这样做，以 unpkg 举例

```html
<script src="//unpkg.com/vue-cesium@next">
  app.use(VueCesium, {
    locale: VueCesium.lang.zh
  })
</script>
``` -->

[支持的语言列表](https://github.com/zouyaoji/vue-cesium/tree/dev/packages/locale/lang)

<ul class="language-list">
  <li>简体中文（zh-hans）</li>
  <li>英文（en-us）</li>
</ul>

如果你需要使用其他的语言，欢迎贡献 [PR](https://github.com/zouyaoji/vue-cesium/pulls) 只需在[这里](https://github.com/zouyaoji/vue-cesium/tree/dev/packages/locale/lang) 添加一个语言配置文件即可。
